bibliotheca Augustana

<<< Übersicht <<< vorige Seite nächste Seite >>>
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Handschrift B ## 12. Aventiure
___________________________________________________
| ### <Nv> gedaht ovch alle cite daz Gvnthers wip ### wi treit et also hohe vrov Crhiemhilt den lip ### nv ist doch vnser eigen Sifrit ir man ### er hat vns nv vil lange lvecel dienste getan ### Diz trvch si in ir hercen vnt wart ovch wol verdeit ### daz si ir vremede waren daz was ir harte leit ### daz man ir so selten diente von Sifrides lant ### wa von daz were <daz> hete si gerne bechant
###### 723 | ### Si versvchtez an dem chvenige ob iz mohte geschehen ### daz si Criemhilde solde noch gesehen ### si <reitez> hæinliche des si da hete [323b] mvt ### do dvhte den herren div rede mæzlichen gvt
| ### Wi moehte wir si bringen sprach der chvenech rich ### her zv diesm lande daz wære vnmvegelich ### si sitzen vns ce verre ine getar sis niht gebitten ### des antwrte im vrov Prvnnhilt in einen listigen siten
###### 725 | ### swi hohe riche wære deheines chveniges man ### swaz im gebvete sin herre daz sold er doch niht lan ### des ersmielte Gvnther do si daz gesprach ### ern iahes im niht ce dienste swi diche er Sifride sach
###### 726 | ### Si sprach vil lieber herre dvrch den willen min ### so hilf mir daz Sifrit vnt ovch div swester din ### chvmen zv disem lande daz wir si hie gesehen ### sone chvnde mir zware nimmer lieber geshæhen
| ### Diner swester zvehte vnt ir wol gezogener mvt ### swenne ich dar an gedenche wi sampfte mir daz tvt ### wi wir ensamt sazen do ich erste wart din wip ### si mach mit eren minnen des chvenen Sifrides lip
###### 728 | ### Si gertes also lange vnz daz der chvenich sprach ### nv wizet daz ich geste so gerne nie gesach ### ir mveget mich sampfte vlegen ich wil di boten min ### nach in beiden senden daz si vns chomen an den Rin
###### 729 | ### Do sprach div chveneginne so svlt ir mir sagen ### wenne ir si welt besenden oder in welhen tagen ### vnser lieben vrivnde svln chomen in daz lant ### di ir dar wellet senden di lat mir werden bechant
| ### Daz tvn ich sprach der fvrste drizech miner man ### wil ich dar lazen riten di hiez er fver sich gan ### bi den enbot er mære in daz Sifrides lant ### ce liebe gap in Prvnnhilt vil harte herlich gewant
###### 731 | ### Do sprach der chvenich Gvnther ir recken svlt von mir sagen ### al dz ich dar enbiete svlt ir niht verdagen ### dem starchem Sifride vnt ovch der swester min ### daz in endarf ce der werlde niemen holder gesin
###### 732 | ### Vnde pittet daz si beide zv vns chomen an den Rin ### daz welle ich vnt min vrowe immer dienende sin ### vor disen svnewenden sol er vnd sine man ### sehen hie vil manigen der im vil grozer eren gan
| ### Dem chvnige Sigemvnde saget <den> dienest min ### daz ich vnd <di> mine [324a] im immer wæge sin ### vnd saget ovch miner swester daz si niht laze daz ### sine rite zv zir vrivnden ir zam ni hohgeciten baz
###### 734 | ### Prvnnhilt vnt Vte vnt swaz man da vrowen vant ### di enbvten alle ir dienest in Sifrides lant ### den minnechlichen vrowen vnt manigem chvenem man ### mit chveneges vrivnde rate di boten hvben sich dan
###### 735 | ### Si fvren reisliche ir pferht vnd ir gewant ### daz was in chomen allen do rvmten si daz lant ### in zogete wol ir verte dar si <da> wolden varn ### der chvenich hiez mit geleite di boten vlizechliche bewarn
| ### Si chomen in drin wochen geriten in daz lant ### ce Nibelvnges bverge daz waren si gesant ### ce Norwæge in der marche da fvnden si degen ### div ross den boten waren vil mvede von den langen wegen
###### 737 | ### Sifride vnd Criemhilt wart beiden do geseit ### daz ritter dar chomen waren di trvgen solhiv chleit ### sam man cen Bvergende do der site pflach ### si spranch von einem bette dar an si rwende lach
###### 738 | ### Do bat si cenem venster eine magt gan ### div sach den chvenen Gêrên an dem hove stan ### in vnt di gesellen di waren dar gesant ### gegen ir herceleide wi liebiv mære si bevant
| ### Si sprach zv dem chvenige nv seht ir wa si stent ### <di> mit dem starchen Gêrên vff dem hove gent ### di vns min brvder Gvnther sendet nider den Rin ### do sprach der starche Sifrit di svln vns willechomen sin
###### 740 | ### Allez daz gesinde lief da man si sach ### ir ietslich besvnder vil gvetliche sprach ### daz beste daz si chvnden ce boten do ### Sigemvnt der herre der was ir chvmpfte harte vro
###### 741 | ### Do wart geherberget Gere vnt sine man ### div ross hiez man behalten di boten giengen dan ### da der herre Sifrit bi Criemhilde saz ### in was ce hove erlovbet da von so taten si daz
| ### Der wirt mit sinem wibe stvnt vf sa cehant ### wol wart enpfangen Gêrê von Pvrgvnden lant ### mit sinen hergesellen die Gvntheres man ### Geren den vil richen bat man an den sædel gan
###### 743 | ### Erlovbet vns di botschapft ê daz wir sitzen gen ### vns wægemveden geste lat vns di wile sten ### wir sveln iv sagen mære waz iv enboten hat ### Gvnther vnd Prvenhilt ir dinch vil hohenliche stat [324b]
###### 744 | ### vnt ovch waz vrov Vote iwer mvter her enbot ### Giselher der ivnge vnt ovch her Gernot ### vnt iwer besten mage di habent vns her gesant ### di enbietent iv ir dienest vzer Gvntheres lant
| ### Nv lon in got sprach Sifrit ich getrwe in harte wol ### triwen vnt gvtes also man vrivnden sol ### alsam tvt ovch ir swester ir svlt vns mære sagen ### ob vnser lieben vrivnde da heime iht hohes mvtes tragen
###### 746 | ### Sit daz wir von in <shieden> hat in iemen iht getan ### den minen choenemagen daz svlt ir mich wizen lan ### daz wil in immer mit triwen helfen tragen ### vnze daz ir viende den minen dienest mvezen klagen
###### 747 | ### Do sprach der margrave Gêrê ein reche vil gvt ### si sint in allen tvgenden so rehte hoh gemvt ### si ladent ivch ce Rine ceiner hochgecit ### si sæhen ivch vil gerne daz ir des ane zwifel sit
| ### Vnde pitent mine vrowen si svl mit iv dar chvmen ### swenne daz der vient ein ende habe genvmen ### vor disen svnewenden so wolden si ivch sæhen ### do sprach der starche Sifrit daz chvnde mvelich geschæhen
###### 749 | ### Do sprach aber Gêrê von Bvergvnden lant ### iwer mvter Vote hat ivch gemant ### Gernot vnt Giselher ir svlt in niht versagen ### daz ir in sit so verre daz hoer ich tægeliche chlagen
###### 750 | ### Prvennhilt min vrowe vnt alle ir mægedin ### di vrevnt sich der mære vnt ob iz mvege sin ### daz si ivch noch gesæhen daz gæbe in hohen mvt ### do dvhten disiv mære di shoenen Criemhilde gvt
| ### Gere was ir sippe der wirt in sitzen hiez ### den gesten hiez er shenchen niht langer man daz liez ### do was ovch chvmen Sigemvnt da er di boten sach ### der herre vrivnthliche zv den Bvergvnden sprach
###### 752 | ### Sit willechomen ir rechen ir Gvntheres man ### sit daz Criemhilt ce wibe gewan ### Sifrit der min svn man sold ivch dicker sæhen ### hie in disem lande wolt ir <vns> vrivntschepfte iehen
###### 753 | ### Si sprachen swenne er wolde si solden gerne chomen ### in wart ir michel mvede mit vrevden vil benomen ### di boten bat man sitzen spise man in trvch ### do hiez do gæben Sifrit sinen gesten genvch
| ### Si mvsen da beliben bevollen niwn tage ### des heten endechlichen di snellen ritter chlage ### daz si niht wider solden riten in ir [325a] lant ### do het der chvnich Sifrit nach sinen vrivnden gesant
###### 755 | ### Er vragte waz si rieten ov si solden sn den Rin ### ez hat nach mir gesendet Gvnther der frivnt min ### er vnt sine mage dvrch eine hochgecit ### nv choem ich im vil gerne want daz sin lant ce verre lit
###### 756 | ### Vnt bitten Criemhilde daz si mit mir var ### nv ratet liebe vrivnde wi sol ich chomen dar ### vnt sold ich herverten dvrch si in drizech lant ### da mvesen dienen gerne hin div Sifrides hant
| ### Do sprachen sine rechen habt ir der reise mvt ### hin cer hohgecite wir raten waz ir tvt ### ir svlt mit tvsent recken riten an den Rin ### so mveget ir wol mit eren da cen Bvrgvnden sin
###### 758 | ### Do sprach von Niderlande der herre Sigemvnt ### welt ir cer hochgecite wan tvt ir mir daz chvnt ### ob iz iv niht versmahet so rit ich mit iv dar ### ich fvere hvndert dægene da mite mer ich iwer schar
###### 759 | ### Vnd welt ir mit vns riten vil lieber vater min ### sprach der chvene Sifrit vil vro sol ich des sin ### iner tagen zwelven so rvm ich miniv lant ### alle di es do gerten den gap man ross vnt ovch gewant
| ### Do der chvenich edele der reise hete mvt ### do hiez man wider riten di snellen boten gvt ### den sinen choenemagen enbot er an den Rin ### er wolde harte gerne da cir hochgeciten sin
###### 761 | ### Sifrit vnt Criemhilt also wir horen sagen ### so vil den boten gaben daz iz niht mohten tragen ### ir moere heim ze lande er was ein richer man ### ir starchen sovmære <di> treip man vroeliche dan
###### 762 | ### Ir volch chleidete Sifrit vnt ovch Sigemvnt ### Eckewart der grave der hiez an der stvnt ### vrowen chleider svchen div besten div man vant ### oder iender chvnd erwærben veber al Sifrides lant
| ### Di sætele zv den schilden bereiten man began ### rittern vnt vrowen di mit in solden dan ### den gap man swaz si wolden daz in niht gebrast ### do braht er sinen vrivnden vil manigen herlichen gast
###### 764 | ### Den boten zogete sere ce lande vf den wægen ### do chom cen Bvergvnden Gere der dægen ### er wart vil wol empfangen do erbeizten si ce tal ### von rossen vnt von moeren fvr den Giselheres sal
###### 765 | ### Di tvmmen vnt di wisen giengen so man [325b] tvt ### vragen vmbe mære do sprach der riter gvt ### swenne ich se sage dem chvenige da horet si cehant ### er gi mit den gesellen da er Gvntheren vant
| ### Der chvnich von grozer liebe von dem sædele spranch ### daz si so balde chomen des sagte er in do danch ### Prvennhilt div schoene Gvnther cem boten sprach ### wi gehabt sich Sifrit von dem mir liebes vil gesach
###### 767 | ### Do sprach der chvene Gere da wart er vrovden rot ### er vnt iwer swester nie vrivnde baz enbot ### so getriwiv mære deheiner slahte man ### als iv der herre Sifrit vnd ovch sin vater hat getan
###### 768 | ### Do sprach ce dem marchgraven des edelen chvniges wip ### nv sagt mir chvmet vns Criemhilt hat noch ir schoner lip ### behalten iht der zvehte der si wol chvnde <pflægen> ### si chvmt iv sicherlichen so sprach do Gere der dægen
| ### Vte bat do drate di boten fver sich gen ### do mohte man ir vrage harte wol versten ### daz si daz horte gerne was Criemhilt noch gesvnt ### er sagete wi er si fvende vnt daz si chome in chvrcer stvnt
###### 770 | ### Ovch wart von in div gabe ce hove niht verdeit ### di in gap her Sifrit golt vnd ovch div chleit ### daz brahte man ce sehene der drier chvenige man ### der ir vil grozen milte wart in danchen getan
###### 771 | ### Er mach sprach do Hagene von im sampfte geben ### ern chvndez niht verswenden vnt solder immer læben ### hort der Nibelvnge beslozen hat sin hant ### hey solder <chvmen> iemer in der Bvergonden lant
| ### Allez daz gesinde vrevte sich dar zv ### daz si chomen solden spate vnt vrv ### ia waren vil vmmvezech der drier chvenege man ### vil manich <hergesidele> man do rihten began
###### 773 | ### Hvnolt der chvene vnd Sindolt der dægen ### di heten vil vmmvoze di zit si mvsen pflægen ### trvhsæzen vnt shenchen ce rihten manige banch ### des half in ovch her Ortwin des sagete in Gvnther danch
###### 774 | ### Rvmolt der chvchenmeister wi wol er rihte sit ### di sinen vndertanen vil manigen kezel wit ### hæven vnt pfannen hey waz man der da vant ### do bereite man do spise di da chomen in [326a] daz lant

<<< Übersicht <<< vorige Seite nächste Seite >>>